@@ -79,6 +79,13 @@ pub fn get_config() -> (Config, usize) {
                 .value_name("file")
                 .takes_value(true)
         )
+        .arg(
+            Arg::with_name("output-format")
+                .short("O")
+                .long("output-format")
+                .help("standart, json, url (default is \"standart\")")
+                .takes_value(true)
+        )
         .arg(
             Arg::with_name("method")
                 .short("X")
@@ -474,6 +481,7 @@ pub fn get_config() -> (Config, usize) {
 
     let mut config = Config {
         method: args.value_of("method").unwrap_or("GET").to_string(),
+        initial_url: args.value_of("url").unwrap_or("").to_string(),
         url,
         host: host.to_string(),
         path,
@@ -488,6 +496,7 @@ pub fn get_config() -> (Config, usize) {
         replay_once: args.is_present("replay-once"),
         output_file: args.value_of("output").unwrap_or("").to_string(),
         save_responses: args.value_of("save-responses").unwrap_or("").to_string(),
+        output_format: args.value_of("output-format").unwrap_or("").to_string(),
         as_body: args.is_present("as-body"),
         force: args.is_present("force"),
         disable_response_correction: args.is_present("disable-response-correction"),
