@@ -68,10 +68,12 @@ pub fn compare(
     (code, diffs)
 }
 
-//get possible parameters from the page source code
+//get possible parameters from the page code
 pub fn heuristic(body: &str) -> Vec<String> {
     let mut found: Vec<String> = Vec::new();
 
+    let re_special_chars = Regex::new(r#"[\W]"#).unwrap();
+
     let re_name = Regex::new(r#"(?i)name=("|')?"#).unwrap();
     let re_inputs = Regex::new(r#"(?i)name=("|')?[\w-]+"#).unwrap();
     for cap in re_inputs.captures_iter(body) {
@@ -84,10 +86,14 @@ pub fn heuristic(body: &str) -> Vec<String> {
         found.push(re_var.replace_all(&cap[0], "").to_string());
     }
 
-    let re_quotes = Regex::new(r#"("|')"#).unwrap();
     let re_words_in_quotes = Regex::new(r#"("|')\w{3,20}('|")"#).unwrap();
     for cap in re_words_in_quotes.captures_iter(body) {
-        found.push(re_quotes.replace_all(&cap[0], "").to_string());
+        found.push(re_special_chars.replace_all(&cap[0], "").to_string());
+    }
+
+    let re_words_within_objects = Regex::new(r#"[\{,]\s*[[:alpha:]]\w{2,25}:"#).unwrap();
+    for cap in re_words_within_objects.captures_iter(body){
+        found.push(re_special_chars.replace_all(&cap[0], "").to_string());
     }
 
     found.sort();
@@ -173,20 +179,27 @@ pub async fn generate_data(config: &Config, client: &Client, query: &HashMap<Str
         response.code,
         response.text
     ).ok();
+
+    writeln!(
+        io::stdout(),
+        "Possible parameters: {}",
+        heuristic(&response.text).join(", ")
+    ).ok();
 }
 
 //Add %s if it is absent in the body
 pub fn adjust_body(body: &str, t: &str) -> String {
     let mut body = body.to_string();
 
-    if t.contains("json") && !body.is_empty() {
+    //if type is json and body has parameters -> add an injection to the end
+    if t.contains("json") && !body.is_empty() && body.contains('"') {
         body.pop();
         body.push_str(", %s}");
         body
     } else if t.contains("json") {
-        body.push_str("{%s}");
-        body
-    } else if !body.is_empty() {
+        String::from("{%s}")
+    //suppose that body type is urlencode
+    } else if !body.is_empty()  {
         body.push_str("&%s");
         body
     } else {
@@ -273,13 +286,21 @@ pub fn check_diffs(
 pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Config> {
     let mut lines = request.lines();
     let mut host = String::new();
+    let mut content_type = String::new();
     let mut headers: HashMap<String, String> = config.headers.clone();
     let proto = if insecure { "http://" } else { "https://" };
     let mut firstline = lines.next()?.split(' ');
     let method = firstline.next()?.to_string();
     let path = firstline.next()?.to_string();
-    let mut parameter_template = String::from("%k=%v&");
 
+    let http2: bool = firstline.next()?.to_string().contains("HTTP/2");
+
+    let mut parameter_template = match config.body_type == "json" {
+        true => String::from("\"%k\":\"%v\", "),
+        false => String::from("%k=%v&")
+    };
+
+    //read headers
     while let Some(line) = lines.next() {
         if line.is_empty() {
             break;
@@ -292,24 +313,29 @@ pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Co
             k_v.map(|x| ":".to_owned() + x).collect(),
         ].concat();
 
-        if key.to_lowercase() == "host" {
-            host = value.clone();
-        }
+        match key.to_lowercase().as_str() {
+            "content-type" => content_type = value.clone(),
+            "host" => host = value.clone(),
+            "content-length" => continue,
+            _ => ()
+        };
 
-        if key.to_lowercase() == "content-length" {
-            continue;
-        }
         headers.insert(key.to_string(), value);
     }
 
     let body = lines.next().unwrap_or("");
-    let body_type = if config.body_type.contains('-') && !body.is_empty() && body.starts_with('{') {
+
+    //check whether the body type can be json
+    let body_type = if config.body_type.contains('-') && config.as_body
+    && (content_type.contains("json") || (!body.is_empty() && body.starts_with('{'))) {
         parameter_template = String::from("\"%k\":\"%v\", ");
         String::from("json-")
     } else {
         config.body_type
     };
-    let body = if !body.is_empty() && !body.contains("%s") && config.as_body {
+
+    //if --as-body is specified and body is empty or lacks injection points - add an injection point
+    let body = if config.as_body && ((!body.is_empty() && !body.contains("%s")) || body.is_empty()) {
         adjust_body(body, &body_type)
     } else {
         body.to_string()
@@ -331,6 +357,7 @@ pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Co
         body,
         body_type,
         parameter_template,
+        http2,
         ..config
     })
 }
@@ -353,17 +380,21 @@ where
 pub fn create_output(config: &Config, found_params: Vec<String>) -> String {
     match config.output_format.as_str() {
         "url" => {
-            let mut line = config.initial_url.to_owned()+"?";
+            let mut line = match config.initial_url.contains('?') {
+                true => config.initial_url.to_owned()+"&",
+                false => config.initial_url.to_owned()+"?"
+            };
 
             for param in &found_params {
                 line.push_str(&param);
-                if !param.contains("=") {
+                if !param.contains('=') {
                     line.push('=');
                     line.push_str(&random_line(config.value_size));
                 }
                 line.push('&')
             }
             line.pop();
+            line.push('\n');
 
             line
         }
@@ -382,7 +413,7 @@ pub fn create_output(config: &Config, found_params: Vec<String>) -> String {
             }
 
             let mut line = line[..line.len() - 2].to_string();
-            line.push_str("]}");
+            line.push_str("]}\n");
             line
         },
         _ => {
@@ -393,7 +424,9 @@ pub fn create_output(config: &Config, found_params: Vec<String>) -> String {
                 line.push_str(", ")
             }
 
-            line[..line.len() - 2].to_string()
+            line = line[..line.len() - 2].to_string();
+            line.push('\n');
+            line
         },
     }
 }
